##
##  libhx.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2022 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         libhx
Summary:      Data Structure Library
URL:          http://libhx.sourceforge.net/
Vendor:       Jan Engelhardt
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Libraries
License:      GPL/LGPL
Version:      4.7
Release:      20221023

#   list of sources
Source0:      http://download.sourceforge.net/libhx/libHX-%{version}.tar.xz

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, make, gcc, gcc::with_cxx = yes
PreReq:       OpenPKG, openpkg >= 20160101

%description
    libHX is a C library (with some additional C++ bindings available)
    that provides data structures and functions for tasks common in
    scripting languages; autoresizing string manipulation, maps, deques,
    option parsing, type-checking casts and more. libHX aids in quickly
    writing up C/C++ data processing programs, by consolidating tasks
    that often happen to be open-coded, such as config file reading,
    option parsing, directory traversal, and others, into a library. The
    focus is on reducing the amount of time (and secondarily, the amount
    of code) a developer has to spend for otherwise implementing such.
    Subsequently, proficient coders can use this to code as fast as for
    a scripting language.

%track
    prog libhx = {
        version   = %{version}
        url       = http://sourceforge.net/projects/libhx/files/
        regex     = libHX-(__VER__)\.tar\.xz
    }

%prep
    %setup -q -n libHX-%{version}

%build
    CC="%{l_cc}" \
    CXX="%{l_cxx}" \
    CFLAGS="%{l_cflags -O}" \
    CXXFLAGS="%{l_cxxflags -O}" \
    CPPFLAGS="%{l_cppflags}" \
    LDFLAGS="%{l_ldflags}" \
    ./configure \
        --prefix=%{l_prefix} \
        --disable-shared
    %{l_make} %{l_mflags -O}

%install
    %{l_make} %{l_mflags} install AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/share/doc >/dev/null 2>&1 || true
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

